@@ -56,6 +56,7 @@ func NewCmdCommentAdd() *cobra.Command {
 	cmd.Flags().Bool("web", false, "Open issue in web browser after adding comment")
 	cmd.Flags().StringP("template", "T", "", "Path to a file to read comment body from")
 	cmd.Flags().Bool("no-input", false, "Disable prompt for non-required fields")
+	cmd.Flags().Bool("internal", false, "Make comment internal")
 
 	return &cmd
 }
@@ -102,7 +103,7 @@ func add(cmd *cobra.Command, args []string) {
 		s := cmdutil.Info("Adding comment")
 		defer s.Stop()
 
-		return client.AddIssueComment(ac.params.issueKey, ac.params.body)
+		return client.AddIssueComment(ac.params.issueKey, ac.params.body, ac.params.internal)
 	}()
 	cmdutil.ExitIfError(err)
 
@@ -122,6 +123,7 @@ type addParams struct {
 	body     string
 	template string
 	noInput  bool
+	internal bool
 	debug    bool
 }
 
@@ -145,11 +147,15 @@ func parseArgsAndFlags(args []string, flags query.FlagParser) *addParams {
 	noInput, err := flags.GetBool("no-input")
 	cmdutil.ExitIfError(err)
 
+	internal, err := flags.GetBool("internal")
+	cmdutil.ExitIfError(err)
+
 	return &addParams{
 		issueKey: issueKey,
 		body:     body,
 		template: template,
 		noInput:  noInput,
+		internal: internal,
 		debug:    debug,
 	}
 }
