@@ -71,17 +71,17 @@ func Info(msg string) *spinner.Spinner {
 
 // Success prints success message in stdout.
 func Success(msg string, args ...interface{}) {
-	fmt.Fprintf(os.Stdout, fmt.Sprintf("\n\u001B[0;32m✓\u001B[0m %s\n", msg), args...)
+	_, _ = fmt.Fprintf(os.Stdout, fmt.Sprintf("\n\u001B[0;32m✓\u001B[0m %s\n", msg), args...)
 }
 
 // Warn prints warning message in stderr.
 func Warn(msg string, args ...interface{}) {
-	fmt.Fprintf(os.Stderr, fmt.Sprintf("\u001B[0;33m%s\u001B[0m\n", msg), args...)
+	_, _ = fmt.Fprintf(os.Stderr, fmt.Sprintf("\u001B[0;33m%s\u001B[0m\n", msg), args...)
 }
 
 // Fail prints failure message in stderr.
 func Fail(msg string, args ...interface{}) {
-	fmt.Fprintf(os.Stderr, fmt.Sprintf("\u001B[0;31m✗\u001B[0m %s\n", msg), args...)
+	_, _ = fmt.Fprintf(os.Stderr, fmt.Sprintf("\u001B[0;31m✗\u001B[0m %s\n", msg), args...)
 }
 
 // Failed prints failure message in stderr and exits.
