@@ -12,7 +12,6 @@ import (
 
 func TestIssueData(t *testing.T) {
 	issue := IssueList{
-		Total:   2,
 		Project: "TEST",
 		Server:  "https://test.local",
 		Data:    getIssues(),
@@ -42,7 +41,6 @@ func TestIssueRenderInPlainView(t *testing.T) {
 	var b bytes.Buffer
 
 	issue := IssueList{
-		Total:   2,
 		Project: "TEST",
 		Server:  "https://test.local",
 		Data:    getIssues(),
@@ -52,7 +50,7 @@ func TestIssueRenderInPlainView(t *testing.T) {
 			NoTruncate: false,
 		},
 	}
-	assert.NoError(t, issue.renderPlain(&b))
+	assert.NoError(t, issue.renderPlain(&b, "\t"))
 
 	expected := `TYPE	KEY	SUMMARY	STATUS
 Bug	TEST-1	This is a test	Done
@@ -61,11 +59,32 @@ Story	TEST-2	This is another test	Open
 	assert.Equal(t, expected, b.String())
 }
 
+func TestIssueRenderInPlainViewWithCustomDelimiter(t *testing.T) {
+	var b bytes.Buffer
+
+	issue := IssueList{
+		Project: "TEST",
+		Server:  "https://test.local",
+		Data:    getIssues(),
+		Display: DisplayFormat{
+			Plain:      true,
+			NoHeaders:  false,
+			NoTruncate: false,
+		},
+	}
+	assert.NoError(t, issue.renderPlain(&b, "|"))
+
+	expected := `TYPE|KEY|SUMMARY|STATUS
+Bug|TEST-1|This is a test|Done
+Story|TEST-2|This is another test|Open
+`
+	assert.Equal(t, expected, b.String())
+}
+
 func TestIssueRenderInPlainViewAndNoTruncate(t *testing.T) {
 	var b bytes.Buffer
 
 	issue := IssueList{
-		Total:   2,
 		Project: "TEST",
 		Server:  "https://test.local",
 		Data:    getIssues(),
@@ -75,7 +94,7 @@ func TestIssueRenderInPlainViewAndNoTruncate(t *testing.T) {
 			NoTruncate: true,
 		},
 	}
-	assert.NoError(t, issue.renderPlain(&b))
+	assert.NoError(t, issue.renderPlain(&b, "\t"))
 
 	expected := `TYPE	KEY	SUMMARY	STATUS	ASSIGNEE	REPORTER	PRIORITY	RESOLUTION	CREATED	UPDATED	LABELS
 Bug	TEST-1	This is a test	Done	Person A	Person Z	High	Fixed	2020-12-13 14:05:20	2020-12-13 14:07:20	krakatit
@@ -88,7 +107,6 @@ func TestIssueRenderInPlainViewWithoutHeaders(t *testing.T) {
 	var b bytes.Buffer
 
 	issue := IssueList{
-		Total:   2,
 		Project: "TEST",
 		Server:  "https://test.local",
 		Data:    getIssues(),
@@ -98,7 +116,7 @@ func TestIssueRenderInPlainViewWithoutHeaders(t *testing.T) {
 			NoTruncate: true,
 		},
 	}
-	assert.NoError(t, issue.renderPlain(&b))
+	assert.NoError(t, issue.renderPlain(&b, "\t"))
 
 	expected := `Bug	TEST-1	This is a test	Done	Person A	Person Z	High	Fixed	2020-12-13 14:05:20	2020-12-13 14:07:20	krakatit
 Story	TEST-2	This is another test	Open		Person A	Normal		2020-12-13 14:05:20	2020-12-13 14:07:20	pat,mat
@@ -112,7 +130,6 @@ func TestIssueRenderInPlainViewWithFewColumns(t *testing.T) {
 	data := getIssues()
 
 	issue := IssueList{
-		Total:   2,
 		Project: "TEST",
 		Server:  "https://test.local",
 		Data:    data,
@@ -122,7 +139,7 @@ func TestIssueRenderInPlainViewWithFewColumns(t *testing.T) {
 			Columns:   []string{"key", "type", "status", "created"},
 		},
 	}
-	assert.NoError(t, issue.renderPlain(&b))
+	assert.NoError(t, issue.renderPlain(&b, "\t"))
 
 	expected := `KEY	TYPE	STATUS	CREATED
 TEST-1	Bug	Done	2020-12-13 14:05:20
@@ -131,6 +148,49 @@ TEST-2	Story	Open	2020-12-13 14:05:20
 	assert.Equal(t, expected, b.String())
 }
 
+func TestIssueRenderInCSVFormat(t *testing.T) {
+	var b bytes.Buffer
+
+	issue := IssueList{
+		Project: "TEST",
+		Server:  "https://test.local",
+		Data:    getIssues(),
+		Display: DisplayFormat{
+			CSV:        true,
+			NoHeaders:  false,
+			NoTruncate: true,
+		},
+	}
+	assert.NoError(t, issue.renderCSV(&b))
+
+	expected := `TYPE,KEY,SUMMARY,STATUS,ASSIGNEE,REPORTER,PRIORITY,RESOLUTION,CREATED,UPDATED,LABELS
+Bug,TEST-1,This is a test,Done,Person A,Person Z,High,Fixed,2020-12-13 14:05:20,2020-12-13 14:07:20,krakatit
+Story,TEST-2,This is another test,Open,,Person A,Normal,,2020-12-13 14:05:20,2020-12-13 14:07:20,"pat,mat"
+`
+	assert.Equal(t, expected, b.String())
+}
+
+func TestIssueRenderInCSVFormatWithoutHeaders(t *testing.T) {
+	var b bytes.Buffer
+
+	issue := IssueList{
+		Project: "TEST",
+		Server:  "https://test.local",
+		Data:    getIssues(),
+		Display: DisplayFormat{
+			CSV:        true,
+			NoHeaders:  true,
+			NoTruncate: true,
+		},
+	}
+	assert.NoError(t, issue.renderCSV(&b))
+
+	expected := `Bug,TEST-1,This is a test,Done,Person A,Person Z,High,Fixed,2020-12-13 14:05:20,2020-12-13 14:07:20,krakatit
+Story,TEST-2,This is another test,Open,,Person A,Normal,,2020-12-13 14:05:20,2020-12-13 14:07:20,"pat,mat"
+`
+	assert.Equal(t, expected, b.String())
+}
+
 func getIssues() []*jira.Issue {
 	return []*jira.Issue{
 		{
