@@ -47,9 +47,7 @@ func TestEpicIssues(t *testing.T) {
 	assert.NoError(t, err)
 
 	expected := &SearchResult{
-		StartAt:    0,
-		MaxResults: 50,
-		Total:      3,
+		IsLast: true,
 		Issues: []*Issue{
 			{
 				Key: "TEST-1",
