@@ -10,30 +10,29 @@ import (
 
 // SearchResult struct holds response from /search endpoint.
 type SearchResult struct {
-	StartAt    int      `json:"startAt"`
-	MaxResults int      `json:"maxResults"`
-	Total      int      `json:"total"`
-	Issues     []*Issue `json:"issues"`
+	IsLast        bool     `json:"isLast"`
+	NextPageToken string   `json:"nextPageToken"`
+	Issues        []*Issue `json:"issues"`
 }
 
 // Search searches for issues using v3 version of the Jira GET /search endpoint.
-func (c *Client) Search(jql string, from, limit uint) (*SearchResult, error) {
-	return c.search(jql, from, limit, apiVersion3)
+func (c *Client) Search(jql string, limit uint) (*SearchResult, error) {
+	path := fmt.Sprintf("/search/jql?jql=%s&maxResults=%d&fields=*all", url.QueryEscape(jql), limit)
+	return c.search(path, apiVersion3)
 }
 
 // SearchV2 searches an issues using v2 version of the Jira GET /search endpoint.
 func (c *Client) SearchV2(jql string, from, limit uint) (*SearchResult, error) {
-	return c.search(jql, from, limit, apiVersion2)
+	path := fmt.Sprintf("/search?jql=%s&startAt=%d&maxResults=%d", url.QueryEscape(jql), from, limit)
+	return c.search(path, apiVersion2)
 }
 
-func (c *Client) search(jql string, from, limit uint, ver string) (*SearchResult, error) {
+func (c *Client) search(path, ver string) (*SearchResult, error) {
 	var (
 		res *http.Response
 		err error
 	)
 
-	path := fmt.Sprintf("/search?jql=%s&startAt=%d&maxResults=%d", url.QueryEscape(jql), from, limit)
-
 	switch ver {
 	case apiVersion2:
 		res, err = c.GetV2(context.Background(), path, nil)
